=========
Changelog
=========

Version 0.1.2
=============

- Minor changes in styling, package requirements and conda environments

Version 0.1.1
=============

- Minor changes in setup.cfg

Version 0.1.0
=============

- First release
